# Changelog

<!--next-version-placeholder-->

## v1.1.1 (2023-06-14)
### Documentation
* **readme:** Change fixed image height to width for responsiveness ([`4ea3557`](https://github.com/trialandsuccess/configuraptor/commit/4ea3557e4cbb6eb2d3128a871209920f27e033ce))

## v1.1.0 (2023-06-14)
### Feature
* Added JSON and YAML file loading. ([`e4f920f`](https://github.com/trialandsuccess/configuraptor/commit/e4f920f0ab1ffaebea2b7b5ad64e33f54f034a33))

## v1.0.3 (2023-06-14)
### Fix
* **core:** Checking for a required parameterized type (e.g. list[str]) crashed for a missing key (with the wrong error) ([`68ccc1c`](https://github.com/trialandsuccess/configuraptor/commit/68ccc1c44e29c940d14acd6ce6b49e9885eaa03a))

### Documentation
* **readme:** Added first example code ([`da0b13d`](https://github.com/trialandsuccess/configuraptor/commit/da0b13d6e90fb0d26b1f33d804657a21304be745))
* **changelog:** Manually added changes ([`c1c40ef`](https://github.com/trialandsuccess/configuraptor/commit/c1c40efb568abec30578d38a0a92d97f398fc23b))
* **image:** Set height ([`78896b8`](https://github.com/trialandsuccess/configuraptor/commit/78896b8a53109c22e8c0875195dd486667a432f0))

## v1.0.2 (2023-06-14)
### Documentation
* set image size

### Build
* added `hatch` as dev dependency

## v1.0.1 (2023-06-14)
### Documentation
* Fix changelog and url in readme ([`59bc18b`](https://github.com/trialandsuccess/configuraptor/commit/59bc18ba5d968b5275253d1637d4f5ef3aa3182b))

## v1.0.0 (2023-06-14)
### BREAKING CHANGE
* renamed to 'configuraptor'

### Feature
* **py:** Trying to support python 3.10 ([`9f7b0f7`](https://github.com/trialandsuccess/configuraptor/commit/9f7b0f7b535e44ff95500aa677b3df60e2482bb7))

### Documentation
* **readme:** Fixed urls and extended sections ([`5fecc97`](https://github.com/trialandsuccess/configuraptor/commit/5fecc9728fb3ff1d09198003afbe37683aab6a5c))

## v0.1.0 (2023-06-13)
### Feature

* Work in progress, second beta version with 100% cov ([`37f4fb4`](https://github.com/robinvandernoord/typedconfig/commit/37f4fb4ad28bdaa1b1b78672656fb5558202d131))
* Work in progress, first working beta version without full docs etc. ([`cf90a93`](https://github.com/robinvandernoord/typedconfig/commit/cf90a93b43d293af1337e6156543673e6b540e2d))

### Fix

* **init:** One step closer to a more logical __init__ handling, just no args yet (only kwargs) ([`9274317`](https://github.com/robinvandernoord/typedconfig/commit/92743173885220f169762d298fa0c2692d0bfe04))

### Documentation

* **examples:** Todo: example about the singleton mixin ([`7b6b0c0`](https://github.com/robinvandernoord/typedconfig/commit/7b6b0c08d5900dd94817cbdc13b79c8bf2cf3a2d))

## v0.1.0 (2023-06-05)
### Feature

* Initial version of the demo plugin ([`dc02818`](https://github.com/robinvandernoord/su6-plugin-demo/commit/dc02818b5d361469fa0ca480eee7394628faad89))
